#' The 'rbioacc' package.
#'
#' @description A DESCRIPTION OF THE PACKAGE
#'
#' @name rbioacc-package
#' @aliases rbioacc
#' @useDynLib rbioacc, .registration = TRUE
#' @import methods
#' @import Rcpp
#' @import rstantools
#' @importFrom rstan sampling
#'
#' @references
#' Stan Development Team (NA). RStan: the R interface to Stan. R package version NA. https://mc-stan.org
#'
"_PACKAGE"